@@ -5,48 +5,55 @@ use warnings;
 
 our @ISA = qw(Pake::Task);
 
+sub run_from_dir($){
+
+	my $test_dir = shift;
+	return sub {
+		opendir(DIR, $test_dir);
+       		my @test_files= readdir(DIR); 
+		
+	       @test_files = splice(@test_files,2);
+	       @test_files = map { $test_dir . "/" . $_} @test_files;
+
+	       print "Running test_files: @test_files\n";
+
+	       use Test::Harness;
+	       runtests(@test_files);
+	};
+};
+
 sub new(&){
    my $proto = shift;
    my $class = ref($proto) || $proto;
 
    my $test_dir = shift;
 
-   my $code = sub {
-       opendir(DIR, $test_dir);
-       my @test_files= readdir(DIR); 
-
-       @test_files = splice(@test_files,2);
-       @test_files = map { $test_dir . "/" . $_} @test_files;
-
-       print "Running test_files: @test_files\n";
-
-       use Test::Harness;
-       runtests(@test_files);
-
-   };
-
    my $self  = {};
 
    $self->{"name"} = "Test";
-   $self->{"code"} = $code;
+   $self->{"code"} = run_from_dir($test_dir);
    $self->{"pre"} = [];
 
+   bless ($self, $class);
+
+   $self->register_description($test_dir);
+   Pake::Application::add_task($self);
+
+   return $self;   
+}
+
+sub register_description($){
+   my $self = shift;
+   my $dir = shift;
+
    if(exists Pake::Application::Env()->{"desc"}){
        $self->{"description"} = Pake::Application::Env()->{"desc"};
        delete Pake::Application::Env()->{"desc"};
    } else {
-       $self->{"description"} = "-";
+       $self->{"description"} = "Execute tests from $dir dir";
    }
-
-   bless ($self, $class);
-   Pake::Application::add_task($self);
-
-   return $self;   
-
 }
 
-default "Test";
-
 1;
 
 __END__
@@ -69,7 +76,6 @@ Other way is to make default task Test:
 
     default "Test";
 
-
 =head1 Description
 
 TestTask executes tests in a specified directory.
